@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.0505';
+our $VERSION = '0.06';
 
 use Moo;
 use strictures 2;
@@ -32,18 +32,21 @@ has text => (
 has sentences => (
     is       => 'rw',
     init_arg => undef,
+    default  => sub { [] },
 );
 
 
 has scores => (
     is       => 'rw',
     init_arg => undef,
+    default  => sub { [] },
 );
 
 
 has nrc_scores => (
     is       => 'rw',
     init_arg => undef,
+    default  => sub { [] },
 );
 
 
@@ -52,7 +55,8 @@ sub analyze {
 
     my $contents = $self->file ? read_text( $self->file ) : $self->text;
 
-    $self->sentences( get_sentences($contents) );
+    $self->sentences( get_sentences($contents) )
+        unless @{ $self->sentences };
 
     my @sentences = map { $_ } @{ $self->sentences };
 
@@ -104,7 +108,8 @@ sub nrc_sentiment {
 
     my $contents = $self->file ? read_text( $self->file ) : $self->text;
 
-    $self->sentences( get_sentences($contents) );
+    $self->sentences( get_sentences($contents) )
+        unless @{ $self->sentences };
 
     my @sentences = map { $_ } @{ $self->sentences };
 
@@ -150,7 +155,7 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.0505
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -167,11 +172,12 @@ version 0.0505
 
 A C<Lingua::EN::Opinion> measures the emotional sentiment of text.
 
-NOTE: This module is over 3MB because of the GIANT sentiment text it comes with.
+NOTE: This module is over 3MB uncompressed because of the GIANT sentiment text
+it comes with.
 
 Please see the F<eg/> and F<t/> scripts for example usage.
 
-The write-up illustrating usage and results can be found at
+The write-up illustrating results can be found at
 L<http://techn.ology.net/book-of-revelation-sentiment-analysis/>
 
 =head1 ATTRIBUTES
@@ -208,8 +214,8 @@ Create a new C<Lingua::EN::Opinion> object.
 
   $opinion->analyze();
 
-Measure the emotional sentiment of text.  This method sets the B<scores>
-and B<sentences> attributes.
+Measure the positive/negative emotional sentiment of text.  This method sets the
+B<scores> and B<sentences> attributes.
 
 =head2 averaged_score()
 
